Rust bindings to Fundamentum edge daemon’s gRPC IDL files. A library that
provides a Rust representation of the basic types, interfaces and other
components required to define and interact with the gRPC interface defined
by fundamentum-edge-proto.
Current direct users:
fundamentum-edge-daemon: the actual edge daemon server implementation.
Note that this component’s version is intentionally distinct from the underlying protocol.
See branch (line 8) in the prototobufs’ .gitrepo for the underlying protocol’s version.
Feature flags
-
server: build and expose gRPC server building blocks. -
client: build and expose gRPC client building blocks. -
reflection: build and expose gRPC reflection building blocks.Use this alongside with the
serverflag if your gRPC server is to provide a reflection service for runtime service discovery.An encoded
FileDescriptorSetwill be made available asFILE_DESCRIPTOR_SET.See tonic/examples/src/reflection/server.rs for a good example of adding such reflection service to your gRPC server.
Note that all of the above feature flags are active by default.
Modules
Constants
- FILE_
DESCRIPTOR_ SET - Encoded
FileDescriptorSetyou will need if your gRPC server is to provide a reflection service for runtime service discovery.